@@ -32,11 +32,7 @@ from typing import Any
 
 from airflow.configuration import conf as airflow_conf
 from airflow.exceptions import AirflowException
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.common.compat.sdk import BaseHook
 from airflow.security.kerberos import renew_from_kt
 from airflow.utils.log.logging_mixin import LoggingMixin
 
@@ -283,14 +279,14 @@ class SparkSubmitHook(BaseHook, LoggingMixin):
             if not self.spark_binary:
                 self.spark_binary = extra.get("spark-binary", DEFAULT_SPARK_BINARY)
                 if self.spark_binary is not None and self.spark_binary not in ALLOWED_SPARK_BINARIES:
-                    raise RuntimeError(
-                        f"The spark-binary extra can be on of {ALLOWED_SPARK_BINARIES} and it"
+                    raise ValueError(
+                        f"The spark-binary extra can be one of {ALLOWED_SPARK_BINARIES} and it"
                         f" was `{self.spark_binary}`. Please make sure your spark binary is one of the"
                         f" allowed ones and that it is available on the PATH"
                     )
             conn_spark_home = extra.get("spark-home")
             if conn_spark_home:
-                raise RuntimeError(
+                raise ValueError(
                     "The `spark-home` extra is not allowed any more. Please make sure one of"
                     f" {ALLOWED_SPARK_BINARIES} is available on the PATH, and set `spark-binary`"
                     " if needed."
@@ -604,8 +600,8 @@ class SparkSubmitHook(BaseHook, LoggingMixin):
         :param itr: An iterator which iterates over the input of the subprocess
         """
         # Consume the iterator
-        for line in itr:
-            line = line.strip()
+        for line_raw in itr:
+            line = line_raw.strip()
             # If we run yarn cluster mode, we want to extract the application id from
             # the logs so we can kill the application when we stop it unexpectedly
             if self._is_yarn and self._connection["deploy_mode"] == "cluster":
@@ -656,8 +652,8 @@ class SparkSubmitHook(BaseHook, LoggingMixin):
         driver_found = False
         valid_response = False
         # Consume the iterator
-        for line in itr:
-            line = line.strip()
+        for line_raw in itr:
+            line = line_raw.strip()
 
             # A valid Spark status response should contain a submissionId
             if "submissionId" in line:
